@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2010-2016 LabKey Corporation
+# Copyright (c) 2010-2017 LabKey Corporation
 # 
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -453,7 +453,7 @@ RlabkeyUsersGuide <- function(view=TRUE)
 
 .onLoad<- function(libname, pkgname)
 {	
-	try(utils::winMenuAddItem("Vignettes", "Rlabkey", "RlabkeyUsersGuide()"), TRUE)
+	#try(utils::winMenuAddItem("Vignettes", "Rlabkey", "RlabkeyUsersGuide()"), TRUE)
 }
 
 .onUnload<- function(libpath)
